:mod:`gidgetlab.aiohttp` --- aiohttp support
============================================

.. module:: gidgetlab.aiohttp

.. autoclass:: gidgetlab.aiohttp.GitLabAPI


This module even provides a :class:`GitLabBot` class to create simple aiohttp web server
that handles GitLab webhooks.

.. autoclass:: gidgetlab.aiohttp.GitLabBot
   :members:
   :member-order: bysource
